@@ -1,22 +1,22 @@
 import datetime
-from functools import partial as functools_partial
+from functools import partial
 
 import numpy
 
 import cftime
 
-from numpy import around     as numpy_around
-from numpy import array      as numpy_array
+from numpy import around as numpy_around
+from numpy import array as numpy_array
 from numpy import asanyarray as numpy_asanyarray
-from numpy import ndarray    as numpy_ndarray
-from numpy import ndim       as numpy_ndim
-from numpy import vectorize  as numpy_vectorize
+from numpy import ndarray as numpy_ndarray
+from numpy import ndim as numpy_ndim
+from numpy import vectorize as numpy_vectorize
 
-from numpy.ma import isMA         as numpy_ma_isMA
-from numpy.ma import is_masked    as numpy_ma_is_masked
-from numpy.ma import masked_all   as numpy_ma_masked_all
+from numpy.ma import isMA as numpy_ma_isMA
+from numpy.ma import is_masked as numpy_ma_is_masked
+from numpy.ma import masked_all as numpy_ma_masked_all
 from numpy.ma import masked_where as numpy_ma_masked_where
-from numpy.ma import nomask       as numpy_ma_nomask
+from numpy.ma import nomask as numpy_ma_nomask
 
 from .functions import _DEPRECATION_ERROR_CLASS
 
@@ -41,7 +41,7 @@ _default_calendar = 'gregorian'
 # Mapping of CF calendars to date-time objects
 # --------------------------------------------------------------------
 _datetime_object = {
-     ('',): cftime.datetime,
+     ('',): partial(cftime.datetime, calendar=''),
      (None, 'gregorian', 'standard', 'none'): cftime.DatetimeGregorian,
      ('proleptic_gregorian',): cftime.DatetimeProlepticGregorian,
      ('360_day',): cftime.Datetime360Day,
@@ -139,8 +139,9 @@ def dt(arg, month=1, day=1, hour=0, minute=0, second=0,
             arg)
 
     elif isinstance(arg, cftime.datetime):
-        (year, month, day, hour, minute, second) = arg.timetuple()[:6]
-        microsecond = arg.microsecond
+        (year, month, day, hour, minute, second, microsecond) = (
+            arg.year, arg.month, arg.day, arg.hour, arg.minute, arg.second,
+            arg.microsecond)
         if calendar == '':
             calendar = arg.calendar
 
@@ -290,7 +291,7 @@ def st2dt(array, units_in=None, dummy0=None, dummy1=None):
     **Examples:**
 
     '''
-    func = functools_partial(st2datetime, calendar=units_in._calendar)
+    func = partial(st2datetime, calendar=units_in._calendar)
     return numpy_vectorize(func, otypes=[object])(array)
 
 
@@ -440,7 +441,7 @@ def rt2dt(array, units_in, units_out=None, dummy1=None):
         # There is no missing data
         return numpy_array(array, dtype=object)
         # return numpy_vectorize(
-        #     functools_partial(dt2Dt, calendar=units_in._calendar),
+        #     partial(dt2Dt, calendar=units_in._calendar),
         #     otypes=[object])(array)
     else:
         # There is missing data
@@ -449,7 +450,7 @@ def rt2dt(array, units_in, units_out=None, dummy1=None):
         else:
             # array = numpy_array(array)
             # array = numpy_vectorize(
-            #     functools_partial(dt2Dt, calendar=units_in._calendar),
+            #     partial(dt2Dt, calendar=units_in._calendar),
             #     otypes=[object])(array)
             return numpy_ma_masked_where(mask, array)
 
