@@ -1,4 +1,5 @@
 import csv
+import logging
 import os
 import platform
 import re
@@ -68,8 +69,15 @@ KWARGS_MESSAGE_MAP = {
     "axes": "Use keyword 'axis' instead.",
     "traceback": "Use keyword 'verbose' instead.",
     "exact": "Use 're.compile' objects instead.",
-    "i": "Use keyword 'inplace' instead. Note that when inplace=True, "
-         "None is returned.",
+    "i": (
+        "Use keyword 'inplace' instead. Note that when inplace=True, "
+        "None is returned."
+    ),
+    "info": (
+        "Use keyword 'verbose' instead. Note the informational levels "
+        "have been remapped: V = I + 1 maps info=I to verbose=V inputs, "
+        "excluding I >= 3 which maps to V = -1 (and V = 0 disables messages)"
+    )
 }
 
 # Are we running on GNU/Linux?
@@ -246,6 +254,72 @@ ATOL = cfdm.ATOL
 RTOL = cfdm.RTOL
 CF = cfdm.CF
 
+_disable_logging = cfdm._disable_logging
+# We can inherit the generic logic for the cf-python LOG_LEVEL() function
+# as contained in _log_level, but can't inherit the user-facing LOG_LEVEL()
+# from cfdm as it operates on cfdm's CONSTANTS dict. Define cf-python's own.
+# This also means the LOG_LEVEL dostrings are independent which is important
+# for providing module-specific documentation links and directives, etc.
+_log_level = cfdm._log_level
+_reset_log_emergence_level = cfdm._reset_log_emergence_level
+
+
+def LOG_LEVEL(*log_level):
+    '''The minimal level of seriousness of log messages which are shown.
+
+    This can be adjusted to filter out potentially-useful log messages
+    generated by ``cf`` at runtime, such that any messages marked as
+    having a severity below the level set will not be reported.
+
+    For example, when set to ``'WARNING'`` (or equivalently ``1``),
+    all messages categorised as ``'DEBUG'`` or ``'INFO'`` will be
+    supressed, and only warnings will emerge.
+
+    See https://ncas-cms.github.io/cf-python/tutorial.html#logging for
+    a detailed breakdown on the levels and configuration possibilities.
+
+    The default level is ``'WARNING'`` (``1``).
+
+    .. versionadded:: 3.5.0
+
+    :Parameters:
+
+        log_level: `str` or `int`, optional
+            The new value of the minimal log severity level. This can
+            be specified either as a string equal (ignoring case) to
+            the named set of log levels or identifier 'DISABLE', or an
+            integer code corresponding to each of these, namely:
+
+            * ``'DISABLE'`` (``0``);
+            * ``'WARNING'`` (``1``);
+            * ``'INFO'`` (``2``);
+            * ``'DETAIL'`` (``3``);
+            * ``'DEBUG'`` (``-1``).
+
+    :Returns:
+
+        `str`
+            The value prior to the change, or the current value if no
+            new value was specified (or if one was specified but was
+            not valid). Note the string name, rather than the
+            equivalent integer, will always be returned.
+
+    **Examples:**
+
+    >>> LOG_LEVEL()  # get the current value
+    'WARNING'
+    >>> LOG_LEVEL('INFO')  # change the value to 'INFO'
+    'WARNING'
+    >>> LOG_LEVEL()
+    'INFO'
+    >>> LOG_LEVEL(0)  # set to 'DISABLE' via corresponding integer
+    'INFO'
+    >>> LOG_LEVEL()
+    'DISABLE'
+
+    '''
+    return _log_level(CONSTANTS, log_level)
+
 
 def CHUNKSIZE(*args):
     '''Set the chunksize used by LAMA for partitioning the data
@@ -944,7 +1018,7 @@ def ufunc(name, x, *args, **kwargs):
     return x
 
 
-def _numpy_allclose(a, b, rtol=None, atol=None, verbose=False):
+def _numpy_allclose(a, b, rtol=None, atol=None, verbose=None):
     '''Returns True if two broadcastable arrays have equal values to
     within numerical tolerance, False otherwise.
 
@@ -990,6 +1064,10 @@ def _numpy_allclose(a, b, rtol=None, atol=None, verbose=False):
     True
 
     '''
+    # TODO: we want to use @_manage_log_level_via_verbosity on this function
+    # but we cannot, since importing it to this module would lead to a
+    # circular import dependency with the decorators module. Tentative plan
+    # is to move the function elsewhere. For now, it is not 'loggified'.
 
     # THIS IS WHERE SOME NUMPY FUTURE WARNINGS ARE COMING FROM
 
@@ -1808,7 +1886,7 @@ def abspath(filename):
     '''
     if filename is None:
         return
-    
+
     u = urllib.parse.urlparse(filename)
     if u.scheme != '':
         return filename
@@ -2159,7 +2237,7 @@ def allclose(x, y, rtol=None, atol=None):
     return _numpy_allclose(x, y, rtol=rtol, atol=atol)
 
 
-def _section(o, axes=None, data=False, stop=None, chunks=False,
+def _section(x, axes=None, data=False, stop=None, chunks=False,
              min_step=1, **kwargs):
     '''Return a list of m dimensional sections of a Field of n dimensions
     or a dictionary of m dimensional sections of a Data object of n
@@ -2174,7 +2252,7 @@ def _section(o, axes=None, data=False, stop=None, chunks=False,
 
     :Parameters:
 
-        o: `Field` or `Data`
+        x: `Field` or `Data`
             The `Field` or `Data` object to be sectioned.
 
         axes: optional
@@ -2233,41 +2311,75 @@ def _section(o, axes=None, data=False, stop=None, chunks=False,
     >>> _section(f, ['latitude', 'longitude'], exact=True)
 
     '''
-    # retrieve the index of each axis defining the sections
+    def loop_over_index(x, current_index, axis_indices, indices):
+        '''Expects an index to loop over in the list indices. If this is less
+        than 0 the horizontal slice defined by indices is appended to
+        the FieldList fl, if it is the specified axis indices the
+        value in indices is left as slice(None) and it calls itself
+        recursively with the next index, otherwise each index is
+        looped over. In this loop the routine is called recursively
+        with the next index. If the count of the number of slices
+        taken is greater than or equal to stop it returns before
+        taking any more slices.
+
+        '''
+        if current_index < 0:
+            if data:
+                d[tuple([x.start for x in indices])] = x[tuple(indices)]
+            else:
+                fl.append(x[tuple(indices)])
+
+            nl_vars['count'] += 1
+            return
+
+        if current_index in axis_indices:
+            loop_over_index(x, current_index - 1, axis_indices, indices)
+            return
+
+        for i in range(0, sizes[current_index], steps[current_index]):
+            if stop is not None and nl_vars['count'] >= stop:
+                return
+
+            indices[current_index] = slice(i, i + steps[current_index])
+            loop_over_index(x, current_index - 1, axis_indices, indices)
+    # --- End: def
+
+    # Retrieve the index of each axis defining the sections
     if data:
         if isinstance(axes, int):
             axes = (axes,)
 
         if not axes:
-            axis_indices = range(o.ndim)
+            axis_indices = tuple(range(x.ndim))
         else:
             axis_indices = axes
     else:
-        axis_keys = o.axes(axes, **kwargs)
+        axis_keys = [x.domain_axis(axis, key=True) for axis in axes]
         axis_indices = list()
         for key in axis_keys:
             try:
-                axis_indices.append(o.get_data_axes().index(key))
+                axis_indices.append(x.get_data_axes().index(key))
             except ValueError:
                 pass
     # --- End: if
 
     # find the size of each dimension
-    sizes = o.shape
+    sizes = x.shape
 
     if chunks:
         steps = list(sizes)
 
         # Define the factor which, when multiplied by the size of the
-        # data array, determines how many chunks are in the data array.
+        # data array, determines how many chunks are in the data
+        # array.
         #
         # I.e. factor = 1/(the number of words per chunk)
-        factor = (o.dtype.itemsize + 1.0)/CHUNKSIZE()
+        factor = (x.dtype.itemsize + 1.0)/CHUNKSIZE()
 
-        # n_chunks = number of equal sized bits the partition
-        #            needs to be split up into so that each bit's
-        #            size is less than the chunk size.
-        n_chunks = int(math_ceil(o.size*factor))
+        # n_chunks = number of equal sized bits the partition needs to
+        #            be split up into so that each bit's size is less
+        #            than the chunk size.
+        n_chunks = int(math_ceil(x.size * factor))
 
         for (index, axis_size) in enumerate(sizes):
             if index in axis_indices:
@@ -2295,37 +2407,8 @@ def _section(o, axes=None, data=False, stop=None, chunks=False,
 
     nl_vars = {'count': 0}
 
-    def loop_over_index(current_index):
-        # Expects an index to loop over in the list indices. If this is less
-        # than 0 the horizontal slice defined by indices is appended to the
-        # FieldList fl, if it is the specified axis indices the value in
-        # indices is left as slice(None) and it calls itself recursively with
-        # the next index, otherwise each index is looped over. In this loop
-        # the routine is called recursively with the next index. If the count
-        # of the number of slices taken is greater than or equal to stop
-        # it returns before taking any more slices.
-
-        if current_index < 0:
-            if data:
-                d[tuple([x.start for x in indices])] = o[tuple(indices)]
-            else:
-                fl.append(o[tuple(indices)])
-
-            nl_vars['count'] += 1
-            return
-
-        if current_index in axis_indices:
-            loop_over_index(current_index - 1)
-            return
-
-        for i in range(0, sizes[current_index], steps[current_index]):
-            if stop is not None and nl_vars['count'] >= stop:
-                return
-            indices[current_index] = slice(i, i + steps[current_index])
-            loop_over_index(current_index - 1)
-
     current_index = len(sizes) - 1
-    loop_over_index(current_index)
+    loop_over_index(x, current_index, axis_indices, indices)
 
     if data:
         return d
@@ -2479,6 +2562,7 @@ def environment(display=True, paths=True, string=True):
     else:
         return(out)
 
+
 def default_netCDF_fillvals():
     '''Default data array fill values for each data type.
 
@@ -2505,9 +2589,11 @@ def default_netCDF_fillvals():
     '''
     return netCDF4.default_fillvals
 
+
 def _DEPRECATION_ERROR(message='', version='3.0.0'):
     raise DeprecationError("{}".format(message))
 
+
 def _DEPRECATION_ERROR_ARG(instance, method, arg, message='', version='3.0.0'):
     raise DeprecationError(
         "Argument {2!r} of method '{0}.{1}' has been deprecated at version "
@@ -2520,9 +2606,10 @@ def _DEPRECATION_ERROR_ARG(instance, method, arg, message='', version='3.0.0'):
         )
     )
 
+
 def _DEPRECATION_ERROR_FUNCTION_KWARGS(func, kwargs=None, message='',
                                        exact=False, traceback=False,
-                                       version='3.0.0'):
+                                       info=False, version='3.0.0'):
     # Unsafe to set mutable '{}' as default in the func signature.
     if kwargs is None:  # distinguish from falsy '{}'
         kwargs = {}
@@ -2548,7 +2635,7 @@ def _DEPRECATION_ERROR_FUNCTION_KWARGS(func, kwargs=None, message='',
 def _DEPRECATION_ERROR_KWARGS(instance, method, kwargs=None, message='',
                               i=False, traceback=False, axes=False,
                               exact=False, relaxed_identity=False,
-                              version='3.0.0'):
+                              info=False, version='3.0.0'):
     # Unsafe to set mutable '{}' as default in the func signature.
     if kwargs is None:  # distinguish from falsy '{}'
         kwargs = {}
@@ -2585,6 +2672,7 @@ def _DEPRECATION_ERROR_KWARG_VALUE(
         )
     )
 
+
 def _DEPRECATION_ERROR_METHOD(instance, method, message='', version='3.0.0'):
     raise DeprecationError(
         "{} method {!r} has been deprecated at version {} and is no longer "
