@@ -1,3 +1,4 @@
+import logging
 import os
 
 from ctypes.util import find_library
@@ -10,11 +11,13 @@ from .um     import UMRead
 from ..cfimplementation import implementation
 
 from ..fieldlist import FieldList
-from ..functions import flat
 
 from ..aggregate import aggregate as cf_aggregate
 
-from ..functions import _DEPRECATION_ERROR_FUNCTION_KWARGS
+from ..decorators import _manage_log_level_via_verbosity
+
+from ..functions import flat, _DEPRECATION_ERROR_FUNCTION_KWARGS
+
 
 # --------------------------------------------------------------------
 # Create an implementation container and initialize a read object for
@@ -25,7 +28,11 @@ netcdf = NetCDFRead(_implementation)
 UM = UMRead(_implementation)
 
 
-def read(files, external=None, verbose=False, warnings=False,
+logger = logging.getLogger(__name__)
+
+
+@_manage_log_level_via_verbosity
+def read(files, external=None, verbose=None, warnings=False,
          ignore_read_error=False, aggregate=True, nfields=None,
          squeeze=False, unsqueeze=False, fmt=None, select=None,
          extra=None, recursive=False, followlinks=False, um=None,
@@ -221,10 +228,21 @@ def read(files, external=None, verbose=False, warnings=False,
             `~cf.Field.convert` method of a returned field construct,
             instead of setting the *extra* parameter.
 
-        verbose: `bool`, optional
-            If True then print a description of how the contents of
-            the netCDF file were parsed and mapped to CF data model
-            constructs.
+        verbose: `int` or `None`, optional
+            If an integer from ``0`` to ``3``, corresponding to increasing
+            verbosity (else ``-1`` as a special case of maximal and extreme
+            verbosity), set for the duration of the method call (only) as
+            the minimum severity level cut-off of displayed log messages,
+            regardless of the global configured `cf.LOG_LEVEL`.
+
+            Else, if `None` (the default value), log messages will be
+            filtered out, or otherwise, according to the value of the
+            `cf.LOG_LEVEL` setting.
+
+            Overall, the higher a non-negative integer that is set (up to
+            a maximum of ``3``) the more description that is printed to
+            convey how the contents of the netCDF file were parsed and
+            mapped to CF data model constructs.
 
         warnings: `bool`, optional
             If True then print warnings when an output field construct
@@ -300,17 +318,17 @@ def read(files, external=None, verbose=False, warnings=False,
             values of any of the netCDF variable attributes
             ``_FillValue``, ``missing_value``, ``valid_min``,
             ``valid_max`` and ``valid_range``.
-    
+
             The masking by convention of a PP or UM array depends on
             the value of BMDI in the lookup header. A value other than
             ``-1.0e30`` indicates the data value to be masked.
-    
+
             See
             https://ncas-cms.github.io/cf-python/tutorial.html#data-mask
             for details.
 
             .. versionadded:: 3.4.0
-            
+
         warn_valid: `bool`, optional
             If True then print a warning for the presence of
             ``valid_min``, ``valid_max`` or ``valid_range`` properties
@@ -321,13 +339,13 @@ def read(files, external=None, verbose=False, warnings=False,
             of these properties, are automatically masked by default,
             which may not be as intended. See the *mask* parameter for
             turning off all automatic masking.
-    
+
             See
             https://ncas-cms.github.io/cf-python/tutorial.html#data-mask
             for details.
 
             .. versionadded:: 3.4.0
-            
+
         um: `dict`, optional
             For Met Office (UK) PP files and Met Office (UK) fields
             files only, provide extra decoding instructions. This
@@ -552,8 +570,7 @@ def read(files, external=None, verbose=False, warnings=False,
             files2 = files3
 
         for filename in files2:
-            if verbose:
-                print('File: {0}'.format(filename))  # pragma: no cover
+            logger.info('File: {0}'.format(filename))  # pragma: no cover
 
             if um:
                 ftype = 'UM'
@@ -563,7 +580,7 @@ def read(files, external=None, verbose=False, warnings=False,
                 except Exception as error:
                     if not ignore_read_error:
                         message = error
-                        
+
 #                        if not find_library("umfile"):
 #                            message += ("\n\n"
 #                                "Note: Unable to detect the UM read C library needed "
@@ -576,11 +593,11 @@ def read(files, external=None, verbose=False, warnings=False,
 #                                "reinstall cf-python to try to build the library. "
 #                                "Note a warning will be given if the build fails."
 #                            )
-                                
+
                         raise ValueError(message)
 
-                    if verbose:
-                        print('WARNING: {}'.format(error))  # pragma: no cover
+                    logger.warning(
+                        'WARNING: {}'.format(error))  # pragma: no cover
 
                     continue
             # --- End: if
@@ -622,29 +639,25 @@ def read(files, external=None, verbose=False, warnings=False,
         # --- End: for
     # --- End: for
 
-    # Print some informative messages
-    if verbose:
-        print(
-            "Read {0} field{1} from {2} file{3}".format(
-                field_counter, _plural(field_counter), file_counter,
-                _plural(file_counter)
-            )
-        )  # pragma: no cover
+    logger.info(
+        "Read {0} field{1} from {2} file{3}".format(
+            field_counter, _plural(field_counter), file_counter,
+            _plural(file_counter)
+        )
+    )  # pragma: no cover
 
     # ----------------------------------------------------------------
     # Aggregate the output fields
     # ----------------------------------------------------------------
     if aggregate and len(field_list) > 1:
-        if verbose:
-            org_len = len(field_list)  # pragma: no cover
+        org_len = len(field_list)  # pragma: no cover
 
         field_list = cf_aggregate(field_list, **aggregate_options)
 
-        if verbose:
-            n = len(field_list)  # pragma: no cover
-            print('{0} input field{1} aggregated into {2} field{3}'.format(
-                org_len, _plural(org_len),
-                n, _plural(n)))  # pragma: no cover
+        n = len(field_list)  # pragma: no cover
+        logger.info('{0} input field{1} aggregated into {2} field{3}'.format(
+            org_len, _plural(org_len), n, _plural(n))
+        )  # pragma: no cover
     # --- End: if
 
     # ----------------------------------------------------------------
@@ -699,15 +712,18 @@ def read(files, external=None, verbose=False, warnings=False,
 
     return field_list
 
+
 def _plural(n):  # pragma: no cover
     '''Return a suffix which reflects a word's plural.
 
     '''
     return 's' if n != 1 else ''  # pragma: no cover
 
+
+@_manage_log_level_via_verbosity
 def _read_a_file(filename, ftype=None, aggregate=True,
                  aggregate_options=None, ignore_read_error=False,
-                 verbose=False, warnings=False, external=None,
+                 verbose=None, warnings=False, external=None,
                  selected_fmt=None, um=None, extra=None,
                  height_at_top_of_model=None, chunk=True, mask=True,
                  warn_valid=False):
@@ -738,8 +754,19 @@ def _read_a_file(filename, ftype=None, aggregate=True,
 
             .. versionadded:: 3.4.0
 
-        verbose: `bool`, optional
-            If True then print information to stdout.
+        verbose: `int` or `None`, optional
+            If an integer from ``0`` to ``3``, corresponding to increasing
+            verbosity (else ``-1`` as a special case of maximal and extreme
+            verbosity), set for the duration of the method call (only) as
+            the minimum severity level cut-off of displayed log messages,
+            regardless of the global configured `cf.LOG_LEVEL`.
+
+            Else, if `None` (the default value), log messages will be
+            filtered out, or otherwise, according to the value of the
+            `cf.LOG_LEVEL` setting.
+
+            Overall, the higher a non-negative integer that is set (up to
+            a maximum of ``3``) the more description that is printed.
 
     :Returns:
 
@@ -770,7 +797,7 @@ def _read_a_file(filename, ftype=None, aggregate=True,
             # endian-ness
             if word_size is None:
                 word_size = 4
-                
+
             if endian is None:
                 endian = 'big'
         # --- End: if
@@ -784,8 +811,7 @@ def _read_a_file(filename, ftype=None, aggregate=True,
 #            if not ignore_read_error:
 #                raise Exception(error)
 #
-#            if verbose:
-#                print('WARNING: {}'.format(error))  # pragma: no cover
+#            logger.warning('WARNING: {}'.format(error))  # pragma: no cover
 #
 #            return FieldList()
     # --- End: if
@@ -813,11 +839,10 @@ def _read_a_file(filename, ftype=None, aggregate=True,
 
         if not netcdf.is_netcdf_file(filename):
             if ignore_read_error:
-                if verbose:
-                    print(
-                        "WARNING: Can't determine format of file {} generated "
-                        "from CDL file {}".format(filename, cdl_filename)
-                    )  # pragma: no cover
+                logger.warning(
+                    "WARNING: Can't determine format of file {} generated "
+                    "from CDL file {}".format(filename, cdl_filename)
+                )  # pragma: no cover
 
                 return FieldList()
             else:
@@ -838,7 +863,7 @@ def _read_a_file(filename, ftype=None, aggregate=True,
                          verbose=verbose, set_standard_name=False,
                          height_at_top_of_model=height_at_top_of_model,
                          fmt=fmt, word_size=word_size, endian=endian,
-                         chunk=chunk) #, mask=mask, warn_valid=warn_valid)
+                         chunk=chunk)  # , mask=mask, warn_valid=warn_valid)
 
         # PP fields are aggregated intrafile prior to interfile
         # aggregation
@@ -860,6 +885,7 @@ def _read_a_file(filename, ftype=None, aggregate=True,
     # ----------------------------------------------------------------
     return FieldList(fields)
 
+
 def file_type(filename):
     '''Return the file format.
 
