@@ -6,10 +6,11 @@ from .netcdf import NetCDFWrite
 
 from ..cfimplementation import implementation
 
+from ..decorators import _manage_log_level_via_verbosity
+
 from ..functions import flat
 from ..functions import _DEPRECATION_ERROR_FUNCTION_KWARGS
 
-
 # from . import mpi_on
 mpi_on = False
 if mpi_on:
@@ -21,12 +22,13 @@ if mpi_on:
 netcdf = NetCDFWrite(implementation())
 
 
+@_manage_log_level_via_verbosity
 def write(fields, filename, fmt='NETCDF4', overwrite=True,
           global_attributes=None, file_descriptors=None,
           external=None, Conventions=None, datatype=None,
           least_significant_digit=None, endian='native', compress=0,
           fletcher32=False, shuffle=True, reference_datetime=None,
-          verbose=False, cfa_options=None, mode='w', single=None,
+          verbose=None, cfa_options=None, mode='w', single=None,
           double=None, variable_attributes=None, string=True,
           warn_valid=True, HDF_chunksizes=None, no_shuffle=None,
           unlimited=None):
@@ -432,22 +434,34 @@ def write(fields, filename, fmt='NETCDF4', overwrite=True,
                       ``double=False`` is exactly equivalent to
                       ``single=True``.
 
-       string: `bool`, optional
-           By default string-valued construct data are written as
-           netCDF arrays of type string if the output file format is
-           ``'NETCDF4'``, or of type char with an extra dimension
-           denoting the maximum string length for any other output
-           file format (see the *fmt* parameter). If *string* is False
-           then string-valued construct data are written as netCDF
-           arrays of type char with an extra dimension denoting the
-           maximum string length, regardless of the selected output
-           file format.
+        string: `bool`, optional
+            By default string-valued construct data are written as
+            netCDF arrays of type string if the output file format is
+            ``'NETCDF4'``, or of type char with an extra dimension
+            denoting the maximum string length for any other output
+            file format (see the *fmt* parameter). If *string* is False
+            then string-valued construct data are written as netCDF
+            arrays of type char with an extra dimension denoting the
+            maximum string length, regardless of the selected output
+            file format.
 
-        verbose: `bool`, optional
-            If True then print a summary of how constructs map to output
-            netCDF dimensions, variables and attributes.
-    
-       warn_valid: `bool`, optional
+        verbose: `int` or `None`, optional
+            If an integer from ``0`` to ``3``, corresponding to increasing
+            verbosity (else ``-1`` as a special case of maximal and extreme
+            verbosity), set for the duration of the method call (only) as
+            the minimum severity level cut-off of displayed log messages,
+            regardless of the global configured `cf.LOG_LEVEL`.
+
+            Else, if `None` (the default value), log messages will be
+            filtered out, or otherwise, according to the value of the
+            `cf.LOG_LEVEL` setting.
+
+            Overall, the higher a non-negative integer that is set (up to
+            a maximum of ``3``) the more description that is printed to
+            convey how constructs map to output netCDF dimensions, variables
+            and attributes.
+
+        warn_valid: `bool`, optional
             If False then do not print a warning when writing
             "out-of-range" data, as indicated by the values, if
             present, of any of the ``valid_min``, ``valid_max`` or
@@ -554,7 +568,7 @@ def write(fields, filename, fmt='NETCDF4', overwrite=True,
 
         if single is not None and not single:
             double = True
-            
+
         if double is not None and not double:
             single = True
 
@@ -565,7 +579,7 @@ def write(fields, filename, fmt='NETCDF4', overwrite=True,
         if double:
             datatype = {numpy.dtype('float32'): numpy.dtype(float),
                         numpy.dtype('int32'): numpy.dtype(int)}
-        
+
         extra_write_vars = {
             'cfa': False,
             'cfa_options': {},
